summaryrefslogtreecommitdiff
path: root/vswitchd
diff options
context:
space:
mode:
authorBen Pfaff <blp@ovn.org>2020-06-17 14:16:08 -0700
committerBen Pfaff <blp@ovn.org>2020-10-21 11:28:24 -0700
commit91fc374a9c5a2a4d9520aaa3588a7a18338a476e (patch)
tree36e097d0f7b655e90179c04e21eb7fe4c400889b /vswitchd
parentf51cf36d86e4a51630dc2781034149c13a634d67 (diff)
downloadopenvswitch-91fc374a9c5a2a4d9520aaa3588a7a18338a476e.tar.gz
Eliminate use of term "slave" in bond, LACP, and bundle contexts.
The new term is "member". Most of these changes should not change user-visible behavior. One place where they do is in "ovs-ofctl dump-flows", which will now output "members:..." inside "bundle" actions instead of "slaves:...". I don't expect this to cause real problems in most systems. The old syntax is still supported on input for backward compatibility. Signed-off-by: Ben Pfaff <blp@ovn.org> Acked-by: Alin Gabriel Serdean <aserdean@cloudbasesolutions.com>
Diffstat (limited to 'vswitchd')
-rw-r--r--vswitchd/bridge.c35
-rw-r--r--vswitchd/ovs-vswitchd.8.in42
-rw-r--r--vswitchd/vswitch.xml37
3 files changed, 59 insertions, 55 deletions
diff --git a/vswitchd/ovs-vswitchd.8.in b/vswitchd/ovs-vswitchd.8.in
index c06452928..50dad7208 100644
--- a/vswitchd/ovs-vswitchd.8.in
+++ b/vswitchd/ovs-vswitchd.8.in
@@ -198,46 +198,46 @@ These commands manage bonded ports on an Open vSwitch's bridges. To
understand some of these commands, it is important to understand a
detail of the bonding implementation called ``source load balancing''
(SLB). Instead of directly assigning Ethernet source addresses to
-slaves, the bonding implementation computes a function that maps an
+members, the bonding implementation computes a function that maps an
48-bit Ethernet source addresses into an 8-bit value (a ``MAC hash''
value). All of the Ethernet addresses that map to a single 8-bit
-value are then assigned to a single slave.
+value are then assigned to a single member.
.IP "\fBbond/list\fR"
-Lists all of the bonds, and their slaves, on each bridge.
+Lists all of the bonds, and their members, on each bridge.
.
.IP "\fBbond/show\fR [\fIport\fR]"
Lists all of the bond-specific information (updelay, downdelay, time
until the next rebalance) about the given bonded \fIport\fR, or all
bonded ports if no \fIport\fR is given. Also lists information about
-each slave: whether it is enabled or disabled, the time to completion
+each members: whether it is enabled or disabled, the time to completion
of an updelay or downdelay if one is in progress, whether it is the
-active slave, the hashes assigned to the slave. Any LACP information
+active member, the hashes assigned to the member. Any LACP information
related to this bond may be found using the \fBlacp/show\fR command.
.
-.IP "\fBbond/migrate\fR \fIport\fR \fIhash\fR \fIslave\fR"
-Only valid for SLB bonds. Assigns a given MAC hash to a new slave.
+.IP "\fBbond/migrate\fR \fIport\fR \fIhash\fR \fImember\fR"
+Only valid for SLB bonds. Assigns a given MAC hash to a new member.
\fIport\fR specifies the bond port, \fIhash\fR the MAC hash to be
-migrated (as a decimal number between 0 and 255), and \fIslave\fR the
-new slave to be assigned.
+migrated (as a decimal number between 0 and 255), and \fImember\fR the
+new member to be assigned.
.IP
The reassignment is not permanent: rebalancing or fail-over will
-cause the MAC hash to be shifted to a new slave in the usual
+cause the MAC hash to be shifted to a new member in the usual
manner.
.IP
-A MAC hash cannot be migrated to a disabled slave.
-.IP "\fBbond/set\-active\-slave\fR \fIport\fR \fIslave\fR"
-Sets \fIslave\fR as the active slave on \fIport\fR. \fIslave\fR must
+A MAC hash cannot be migrated to a disabled member.
+.IP "\fBbond/set\-active\-member\fR \fIport\fR \fImember\fR"
+Sets \fImember\fR as the active member on \fIport\fR. \fImember\fR must
currently be enabled.
.IP
-The setting is not permanent: a new active slave will be selected
-if \fIslave\fR becomes disabled.
-.IP "\fBbond/enable\-slave\fR \fIport\fR \fIslave\fR"
-.IQ "\fBbond/disable\-slave\fR \fIport\fR \fIslave\fR"
-Enables (or disables) \fIslave\fR on the given bond \fIport\fR, skipping any
+The setting is not permanent: a new active member will be selected
+if \fImember\fR becomes disabled.
+.IP "\fBbond/enable\-member\fR \fIport\fR \fImember\fR"
+.IQ "\fBbond/disable\-member\fR \fIport\fR \fImember\fR"
+Enables (or disables) \fImember\fR on the given bond \fIport\fR, skipping any
updelay (or downdelay).
.IP
This setting is not permanent: it persists only until the carrier
-status of \fIslave\fR changes.
+status of \fImember\fR changes.
.IP "\fBbond/hash\fR \fImac\fR [\fIvlan\fR] [\fIbasis\fR]"
Returns the hash value which would be used for \fImac\fR with \fIvlan\fR
and \fIbasis\fR if specified.
@@ -245,7 +245,7 @@ and \fIbasis\fR if specified.
.IP "\fBlacp/show\fR [\fIport\fR]"
Lists all of the LACP related information about the given \fIport\fR:
active or passive, aggregation key, system id, and system priority. Also
-lists information about each slave: whether it is enabled or disabled,
+lists information about each member: whether it is enabled or disabled,
whether it is attached or detached, port id and priority, actor
information, and partner information. If \fIport\fR is not specified,
then displays detailed information about all interfaces with CFM
@@ -253,7 +253,7 @@ enabled.
.
.IP "\fBlacp/stats-show\fR [\fIport\fR]"
Lists various stats about LACP PDUs (number of RX/TX PDUs, bad PDUs received)
-and slave state (number of time slave's state expired/defaulted and carrier
+and member state (number of times its state expired/defaulted and carrier
status changed) for the given \fIport\fR. If \fIport\fR is not specified,
then displays stats of all interfaces with LACP enabled.
.SS "DPCTL DATAPATH DEBUGGING COMMANDS"
diff --git a/vswitchd/vswitch.xml b/vswitchd/vswitch.xml
index a6b70a2f9..d0890b843 100644
--- a/vswitchd/vswitch.xml
+++ b/vswitchd/vswitch.xml
@@ -1949,15 +1949,16 @@
<dl>
<dt><code>balance-slb</code></dt>
<dd>
- Balances flows among slaves based on source MAC address and output
- VLAN, with periodic rebalancing as traffic patterns change.
+ Balances flows among members based on source MAC address and
+ output VLAN, with periodic rebalancing as traffic patterns change.
</dd>
<dt><code>active-backup</code></dt>
<dd>
- Assigns all flows to one slave, failing over to a backup slave when
- the active slave is disabled. This is the only bonding mode in which
- interfaces may be plugged into different upstream switches.
+ Assigns all flows to one member, failing over to a backup
+ member when the active member is disabled. This is the
+ only bonding mode in which interfaces may be plugged into different
+ upstream switches.
</dd>
</dl>
@@ -1971,8 +1972,8 @@
<dl>
<dt><code>balance-tcp</code></dt>
<dd>
- Balances flows among slaves based on L3 and L4 protocol information
- such as IP addresses and TCP/UDP ports.
+ Balances flows among members based on L3 and L4 protocol
+ information such as IP addresses and TCP/UDP ports.
</dd>
</dl>
@@ -1987,20 +1988,20 @@
<column name="other_config" key="bond-hash-basis"
type='{"type": "integer"}'>
- An integer hashed along with flows when choosing output slaves in load
- balanced bonds. When changed, all flows will be assigned different
- hash values possibly causing slave selection decisions to change. Does
- not affect bonding modes which do not employ load balancing such as
- <code>active-backup</code>.
+ An integer hashed along with flows when choosing output members
+ in load balanced bonds. When changed, all flows will be assigned
+ different hash values possibly causing member selection
+ decisions to change. Does not affect bonding modes which do not employ
+ load balancing such as <code>active-backup</code>.
</column>
<column name="other_config" key="lb-output-action"
type='{"type": "boolean"}'>
Enable/disable usage of optimized <code>lb_output</code> action for
- balancing flows among output slaves in load balanced bonds in
+ balancing flows among output members in load balanced bonds in
<code>balance-tcp</code>. When enabled, it uses optimized path for
- balance-tcp mode by using rss hash and avoids recirculation.
- This knob does not affect other balancing modes.
+ balance-tcp mode by using rss hash and avoids recirculation. This knob
+ does not affect other balancing modes.
</column>
<column name="other_config" key="bond-primary"
@@ -2390,7 +2391,8 @@
</group>
<column name="bond_active_slave">
- For a bonded port, record the mac address of the current active slave.
+ For a bonded port, record the MAC address of the current active
+ member.
</column>
<group title="Port Statistics">
@@ -2480,7 +2482,8 @@
<li>For the local interface, the default is the lowest-numbered MAC
address among the other bridge ports, either the value of the
<ref table="Port" column="mac"/> in its <ref table="Port"/> record,
- if set, or its actual MAC (for bonded ports, the MAC of its slave
+ if set, or its actual MAC (for bonded ports, the MAC of its
+ member
whose name is first in alphabetical order). Internal ports and
bridge ports that are used as port mirroring destinations (see the
<ref table="Mirror"/> table) are ignored.</li>
diff --git a/vswitchd/bridge.c b/vswitchd/bridge.c
index 103b821bb..5ed7e8234 100644
--- a/vswitchd/bridge.c
+++ b/vswitchd/bridge.c
@@ -330,7 +330,8 @@ static void mirror_destroy(struct mirror *);
static bool mirror_configure(struct mirror *);
static void mirror_refresh_stats(struct mirror *);
-static void iface_configure_lacp(struct iface *, struct lacp_slave_settings *);
+static void iface_configure_lacp(struct iface *,
+ struct lacp_member_settings *);
static bool iface_create(struct bridge *, const struct ovsrec_interface *,
const struct ovsrec_port *);
static bool iface_is_internal(const struct ovsrec_interface *iface,
@@ -1197,11 +1198,11 @@ port_configure(struct port *port)
/* Get name. */
s.name = port->name;
- /* Get slaves. */
- s.n_slaves = 0;
- s.slaves = xmalloc(ovs_list_size(&port->ifaces) * sizeof *s.slaves);
+ /* Get members. */
+ s.n_members = 0;
+ s.members = xmalloc(ovs_list_size(&port->ifaces) * sizeof *s.members);
LIST_FOR_EACH (iface, port_elem, &port->ifaces) {
- s.slaves[s.n_slaves++] = iface->ofp_port;
+ s.members[s.n_members++] = iface->ofp_port;
}
/* Get VLAN tag. */
@@ -1270,16 +1271,16 @@ port_configure(struct port *port)
if (s.lacp) {
size_t i = 0;
- s.lacp_slaves = xmalloc(s.n_slaves * sizeof *s.lacp_slaves);
+ s.lacp_members = xmalloc(s.n_members * sizeof *s.lacp_members);
LIST_FOR_EACH (iface, port_elem, &port->ifaces) {
- iface_configure_lacp(iface, &s.lacp_slaves[i++]);
+ iface_configure_lacp(iface, &s.lacp_members[i++]);
}
} else {
- s.lacp_slaves = NULL;
+ s.lacp_members = NULL;
}
/* Get bond settings. */
- if (s.n_slaves > 1) {
+ if (s.n_members > 1) {
s.bond = &bond_settings;
port_configure_bond(port, &bond_settings);
} else {
@@ -1297,9 +1298,9 @@ port_configure(struct port *port)
/* Clean up. */
free(s.cvlans);
- free(s.slaves);
+ free(s.members);
free(s.trunks);
- free(s.lacp_slaves);
+ free(s.lacp_members);
}
/* Pick local port hardware address and datapath ID for 'br'. */
@@ -2277,8 +2278,8 @@ find_local_hw_addr(const struct bridge *br, struct eth_addr *ea,
} else {
/* Choose the interface whose MAC address will represent the port.
* The Linux kernel bonding code always chooses the MAC address of
* the first slave added to a bond, and the Fedora networking
* scripts always add slaves to a bond in alphabetical order, so
* for compatibility we choose the interface with the name that is
* first in alphabetical order. */
LIST_FOR_EACH (candidate, port_elem, &port->ifaces) {
@@ -2961,7 +2962,7 @@ port_refresh_bond_status(struct port *port, bool force_update)
return;
}
- if (bond_get_changed_active_slave(port->name, &mac, force_update)) {
+ if (bond_get_changed_active_member(port->name, &mac, force_update)) {
struct ds mac_s;
ds_init(&mac_s);
@@ -4505,7 +4506,7 @@ port_configure_lacp(struct port *port, struct lacp_settings *s)
}
static void
-iface_configure_lacp(struct iface *iface, struct lacp_slave_settings *s)
+iface_configure_lacp(struct iface *iface, struct lacp_member_settings *s)
{
int priority, portid, key;
@@ -4601,9 +4602,9 @@ port_configure_bond(struct port *port, struct bond_settings *s)
mac_s = port->cfg->bond_active_slave;
if (!mac_s || !ovs_scan(mac_s, ETH_ADDR_SCAN_FMT,
- ETH_ADDR_SCAN_ARGS(s->active_slave_mac))) {
+ ETH_ADDR_SCAN_ARGS(s->active_member_mac))) {
/* OVSDB did not store the last active interface */
- s->active_slave_mac = eth_addr_zero;
+ s->active_member_mac = eth_addr_zero;
}
/* lb_output action is disabled by default. */
@@ -2277,8 +2278,8 @@ find_local_hw_addr(const struct bridge *br, struct eth_addr *ea,
/* Choose the interface whose MAC address will represent the port.
* The Linux kernel bonding code always chooses the MAC address of
- * the first slave added to a bond, and the Fedora networking
- * scripts always add slaves to a bond in alphabetical order, so
+ * the first member added to a bond, and the Fedora networking
+ * scripts always add members to a bond in alphabetical order, so
* for compatibility we choose the interface with the name that is
* first in alphabetical order. */